# 009

|                              | 009-106       | 009-109                    | 009-104              |
|:-----------------------------|:--------------|:---------------------------|:---------------------|
| bindTime                     | 1718777576682 | 1716981074782              | 1715959596828        |
| createTime                   | 0             | 0                          | 0                    |
| deviceFeatureCode            | 106           | 109                        | 104                  |
| deviceFeatureName            | 106冷暖无节能无功率   | 109AI普通风无风向跟随无八字送风冷暖节能无电功率 | 104冷暖节能无功率           |
| deviceId                     | <redacted>    | <redacted>                 | <redacted>           |
| deviceNickName               | Aircondition  | Aircondition               | Hisense Aircondition |
| deviceTypeCode               | 009           | 009                        | 009                  |
| deviceTypeName               |               |                            |                      |
| offlineState                 | 1             | 1                          | 1                    |
| puid                         | <redacted>    | <redacted>                 | <redacted>           |
| role                         | 2             | 2                          | 1                    |
| roomId                       | 1044364       | 1044364                    | 4349167              |
| roomName                     | default_room  | default_room               | Living Room          |
| seq                          | 0             | 0                          | 0                    |
| statusList.daily_energy_kwh  | 0             | 0                          | 0                    |
| statusList.f-filter          | 0             | 0                          | 0                    |
| statusList.f_e_arkgrille     | 0             | 0                          | 0                    |
| statusList.f_e_dwmachine     | 0             | 0                          | 0                    |
| statusList.f_e_incoiltemp    | 0             | 0                          | 0                    |
| statusList.f_e_incom         | 0             | 0                          | 0                    |
| statusList.f_e_indisplay     | 0             | 0                          | 0                    |
| statusList.f_e_ineeprom      | 0             | 0                          | 0                    |
| statusList.f_e_inele         | 0             | 0                          | 0                    |
| statusList.f_e_infanmotor    | 0             | 0                          | 0                    |
| statusList.f_e_inhumidity    | 0             | 0                          | 0                    |
| statusList.f_e_inkeys        | 0             | 0                          | 0                    |
| statusList.f_e_intemp        | 0             | 0                          | 0                    |
| statusList.f_e_invzero       | 0             | 0                          | 0                    |
| statusList.f_e_inwifi        | 0             | 0                          | 0                    |
| statusList.f_e_outcoiltemp   | 0             | 0                          | 0                    |
| statusList.f_e_outeeprom     | 0             | 0                          | 0                    |
| statusList.f_e_outgastemp    | 0             | 0                          | 0                    |
| statusList.f_e_outtemp       | 0             | 0                          | 0                    |
| statusList.f_e_over_cold     | 0             | 0                          | 0                    |
| statusList.f_e_over_hot      | 0             | 0                          | 0                    |
| statusList.f_e_push          | 0             | 0                          | 0                    |
| statusList.f_e_upmachine     | 0             | 0                          | 0                    |
| statusList.f_e_waterfull     | 0             | 0                          | 0                    |
| statusList.f_electricity     | 0             | 0                          | 0                    |
| statusList.f_humidity        | 128           | 128                        | 128                  |
| statusList.f_temp_in         | 24            | 26                         | 26                   |
| statusList.f_votage          | 220           | 230                        | 228                  |
| statusList.t_dal             | 0             | 0                          | 1                    |
| statusList.t_demand_response | 0             | 0                          | 0                    |
| statusList.t_eco             | 0             | 1                          | 0                    |
| statusList.t_fan_mute        | 0             | 0                          | 0                    |
| statusList.t_fan_speed       | 0             | 0                          | 0                    |
| statusList.t_fan_speed_s     | 0             | 0                          | 0                    |
| statusList.t_fanspeedcv      | 0             | 0                          | 0                    |
| statusList.t_power           | 1             | 0                          | 1                    |
| statusList.t_sleep           | 0             | 0                          | 0                    |
| statusList.t_super           | 0             | 0                          | 0                    |
| statusList.t_swing_angle     | 1             | 3                          | 0                    |
| statusList.t_swing_direction | 0             | 2                          | 5                    |
| statusList.t_swing_follow    | 0             | 0                          | 3                    |
| statusList.t_talr            | 0             | 0                          | 1                    |
| statusList.t_temp            | 20            | 23                         | 23                   |
| statusList.t_temp_compensate | 0             | 0                          | 7                    |
| statusList.t_temp_type       | 0             | 0                          | 0                    |
| statusList.t_tms             | 0             | 0                          | 1                    |
| statusList.t_up_down         | 0             | 0                          | 0                    |
| statusList.t_work_mode       | 3             | 2                          | 2                    |
| useTime                      | 1718777576660 | 1716981074759              | 1715959596807        |
| wifiId                       | <redacted>    | <redacted>                 | <redacted>           |

## Generated from

- [`009`](009-106.json)
- [`009`](009-109.json)
- [`009`](009-104.json)
